.. _configuration:

=============
Config
=============

ANDES uses a config file to store the various options for routines and models.
As discussed in :ref:`andes-misc`, the config file is at
``$HOME/.andes/andes.rc``. The reference for the config fields can be found in
:ref:`configref`.

.. toctree::
    :maxdepth: 3

    config-format
    on-the-fly
    ../../configref
